==> connecto_flutter-0.0.5.tar.gz: example/lib/main.dart <==
import 'package:connecto_flutter/connecto_flutter.dart';
import 'package:flutter/material.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  Connecto analytics = new Connecto(
      writeKey: "xxxxxxxxxxx",
      userId: "xxxxxxxxx",
      applicationName: "connectoSample",
      isDebugModeEnable: true,
      packageName: "com.example.connecto");

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Connecto Example'),
        ),
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              InkWell(
                onTap: () {
                  Map<String, dynamic> map = {
                    "platform": "Android",
                    "language": "English (India)",
                    "country": "India",
                    "vehicle": "car"
                  };
                  analytics.trackScreen(screenName: "Main Screen Plugin", properties: map);
                },
                child: Container(
                  margin: EdgeInsets.only(top: 10),
                  padding: EdgeInsets.all(15),
                  color: Colors.grey[300],
                  child: Text("Send Screen Request"),
                ),
              ),
              InkWell(
                onTap: () {
                  Map<String, dynamic> map = {
                    "platform": "Android",
                    "language": "English (India)",
                    "country": "India",
                    "vehicle": "car"
                  };
                  analytics.trackEvent(event: "Button Click", properties: map);
                },
                child: Container(
                    margin: EdgeInsets.only(top: 10),
                    padding: EdgeInsets.all(15),
                    color: Colors.grey[300],
                    child: Text("Send Event Request")),
              ),
              InkWell(
                onTap: () {
                  Map<String, dynamic> map = {
                    "name": "XYZ",
                    "mobile": "1111111111",
                    "email": "xyz@gamil.com"
                  };
                  analytics.identify(traits: map);
                },
                child: Container(
                    margin: EdgeInsets.only(top: 10),
                    padding: EdgeInsets.all(15),
                    color: Colors.grey[300],
                    child: Text("Send identify request")),
              ),
              InkWell(
                onTap: () {
                  analytics.trackFcmToken(
                      "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx");
                },
                child: Container(
                    margin: EdgeInsets.only(top: 10),
                    padding: EdgeInsets.all(15),
                    color: Colors.grey[300],
                    child: Text("Send Token request")),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> connecto_flutter-0.0.7.tar.gz: example/lib/main.dart <==
import 'package:connecto_flutter/connecto_flutter.dart';
import 'package:flutter/material.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  Connecto analytics = new Connecto(
      writeKey: "xxxxxxxxxxx",
      userId: "xxxxxxxxx",
      applicationName: "connectoSample",
      isDebugModeEnable: true,
      packageName: "com.example.connecto");

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Connecto Example'),
        ),
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              InkWell(
                onTap: () {
                  Map<String, dynamic> map = {
                    "platform": "Android",
                    "language": "English (India)",
                    "country": "India",
                    "vehicle": "car"
                  };
                  analytics.trackScreen(
                      screenName: "Main Screen Plugin", properties: map);
                },
                child: Container(
                  margin: EdgeInsets.only(top: 10),
                  padding: EdgeInsets.all(15),
                  color: Colors.grey[300],
                  child: Text("Send Screen Request"),
                ),
              ),
              InkWell(
                onTap: () {
                  Map<String, dynamic> map = {
                    "platform": "Android",
                    "language": "English (India)",
                    "country": "India",
                    "vehicle": "car"
                  };
                  analytics.trackEvent(event: "Button Click", properties: map);
                },
                child: Container(
                    margin: EdgeInsets.only(top: 10),
                    padding: EdgeInsets.all(15),
                    color: Colors.grey[300],
                    child: Text("Send Event Request")),
              ),
              InkWell(
                onTap: () {
                  Map<String, dynamic> map = {
                    "name": "XYZ",
                    "mobile": "1111111111",
                    "email": "xyz@gamil.com"
                  };
                  analytics.identify(traits: map);
                },
                child: Container(
                    margin: EdgeInsets.only(top: 10),
                    padding: EdgeInsets.all(15),
                    color: Colors.grey[300],
                    child: Text("Send identify request")),
              ),
              InkWell(
                onTap: () {
                  analytics.trackFcmToken(
                      "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx");
                },
                child: Container(
                    margin: EdgeInsets.only(top: 10),
                    padding: EdgeInsets.all(15),
                    color: Colors.grey[300],
                    child: Text("Send Token request")),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
